%define anolis_release 4
Summary: Anolis OS specific rpm configuration files
Name: system-rpm-config
Version: 23
Release: %{anolis_release}%{?dist}
License: MulanPSLv2
URL: https://gitee.com/src-anolis-os/system-rpm-config

# Core rpm settings
Source0: macros
Source1: rpmrc

Source10: MulanPSL 

# gcc specs files for hardened builds
Source50: anolis-hardened-cc1
Source51: anolis-hardened-ld
Source52: anolis-hardened-clang.cfg

# gcc specs files for annobin builds
Source60: anolis-annobin-cc1

# The macros defined by these files are for things that need to be defined
# at srpm creation time when it is not feasible to require the base packages
# that would otherwise be providing the macros. other language/arch specific
# macros should not be defined here but instead in the base packages that can
# be pulled in at rpm build time, this is specific for srpm creation.
Source100: macros.anolis-misc-srpm

# Other misc macros
Source151: macros.dwz
Source152: macros.anolis-misc
Source153: macros.ldconfig
# meson depend on this
Source154: macros.vpath
Source155: macros.forge

# Build policy scripts
# this comes from https://github.com/rpm-software-management/rpm/pull/344
Source201: brp-mangle-shebangs
# for converting llvm LTO bitcode objects into ELF
Source202: brp-llvm-compile-lto-elf

# Dependency generator scripts (deprecated)
Source300: find-provides
Source301: find-requires

# Misc helper scripts
Source400: dist.sh
Source401: gpgverify

# 2016-10-02 snapshots from http://git.savannah.gnu.org/gitweb/?p=config.git
Source500: config.guess
Source501: config.sub

# Dependency generators & their rules
Source602: libsymlink.attr

# BRPs
Source700: brp-ldconfig
Source701: brp-strip-lto

# Convenience lua functions
Source800: common.lua
Source801: forge.lua

BuildArch: noarch
BuildRequires: perl-generators
Requires: coreutils

Requires: rpm >= 4.11.0
Requires: dwz >= 0.4
Requires: zip
Requires: (annobin-plugin-gcc if gcc)

# for brp-mangle-shebangs
Requires: %{_bindir}/find
Requires: %{_bindir}/file
Requires: %{_bindir}/grep
Requires: %{_bindir}/sed
Requires: %{_bindir}/xargs

# for brp-llvm-compile-lto-elf
Requires: (llvm if clang)

Provides: system-rpm-config = %{version}-%{release}
# Temporarily provides, will remove after all packages build
Provides: redhat-rpm-config = 2023
Obsoletes: redhat-rpm-config

Requires: go-srpm-macros
Requires: python3-rpm-macros
Requires: efi-srpm-macros
Requires: perl-srpm-macros
Requires: rust-srpm-macros

%global rrcdir /usr/lib/rpm/anolis

%description
Anolis OS specific rpm configuration files.

%prep
# Not strictly necessary but allows working on file names instead
# of source numbers in install section
%setup -c -T
cp -p %{sources} .

%install
mkdir -p %{buildroot}%{rrcdir}
install -p -m 644 -t %{buildroot}%{rrcdir} macros rpmrc
install -p -m 444 -t %{buildroot}%{rrcdir} anolis-hardened-*
install -p -m 444 -t %{buildroot}%{rrcdir} anolis-annobin-*
install -p -m 755 -t %{buildroot}%{rrcdir} config.*
install -p -m 755 -t %{buildroot}%{rrcdir} dist.sh
install -p -m 755 -t %{buildroot}%{rrcdir} gpgverify
install -p -m 755 -t %{buildroot}%{rrcdir} brp-*

install -p -m 755 -t %{buildroot}%{rrcdir} find-*
mkdir -p %{buildroot}%{rrcdir}/find-provides.d

install -p -m 755 -t %{buildroot}%{rrcdir} brp-*

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -p -m 644 -t %{buildroot}%{_rpmconfigdir}/macros.d macros.*

mkdir -p %{buildroot}%{_fileattrsdir}
install -p -m 644 -t %{buildroot}%{_fileattrsdir} *.attr

mkdir -p %{buildroot}%{_rpmluadir}/anolis/{rpm,srpm}
install -p -m 644 -t %{buildroot}%{_rpmluadir}/anolis common.lua
install -p -m 644 -t %{buildroot}%{_rpmluadir}/anolis/srpm forge.lua

%files
%dir %{rrcdir}
%{rrcdir}/macros
%{rrcdir}/rpmrc
%{rrcdir}/brp-*
%{rrcdir}/dist.sh
%{rrcdir}/gpgverify
%{rrcdir}/anolis-hardened-*
%{rrcdir}/anolis-annobin-*
%{rrcdir}/config.*
%{rrcdir}/find-provides
%{rrcdir}/find-requires
%{rrcdir}/brp-ldconfig
%{_fileattrsdir}/*.attr
%{_rpmconfigdir}/macros.d/macros.*-srpm
%{_rpmconfigdir}/macros.d/macros.dwz
%{_rpmconfigdir}/macros.d/macros.anolis-misc
%{_rpmconfigdir}/macros.d/macros.ldconfig
%{_rpmconfigdir}/macros.d/macros.vpath
%{_rpmconfigdir}/macros.d/macros.forge
%dir %{_rpmluadir}/anolis
%dir %{_rpmluadir}/anolis/srpm
%dir %{_rpmluadir}/anolis/rpm
%{_rpmluadir}/anolis/*.lua
%{_rpmluadir}/anolis/srpm/*.lua
%license MulanPSL

%changelog
* Wed Mar 16 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23.4
- fix __cflags_arch_x86_64

* Thu Mar 15 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23.3
- set rust-srpm-macros as requires

* Thu Mar 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23.2
- add macros.forge and some srpm-macros as Requires

* Tue Feb 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23.1
- init package
